@@ -60,7 +60,9 @@ module Aws::S3
     #
     # @return [self]
     def load
-      resp = @client.get_bucket_logging(bucket: @bucket_name)
+      resp = Aws::Plugins::UserAgent.feature('resource') do
+        @client.get_bucket_logging(bucket: @bucket_name)
+      end
       @data = resp.data
       self
     end
@@ -175,7 +177,9 @@ module Aws::S3
           :retry
         end
       end
-      Aws::Waiters::Waiter.new(options).wait({})
+      Aws::Plugins::UserAgent.feature('resource') do
+        Aws::Waiters::Waiter.new(options).wait({})
+      end
     end
 
     # @!group Actions
@@ -199,6 +203,13 @@ module Aws::S3
     #           },
     #         ],
     #         target_prefix: "TargetPrefix", # required
+    #         target_object_key_format: {
+    #           simple_prefix: {
+    #           },
+    #           partitioned_prefix: {
+    #             partition_date_source: "EventTime", # accepts EventTime, DeliveryTime
+    #           },
+    #         },
     #       },
     #     },
     #     content_md5: "ContentMD5",
@@ -216,12 +227,12 @@ module Aws::S3
     #   automatically.
     # @option options [String] :checksum_algorithm
     #   Indicates the algorithm used to create the checksum for the object
-    #   when using the SDK. This header will not provide any additional
-    #   functionality if not using the SDK. When sending this header, there
-    #   must be a corresponding `x-amz-checksum` or `x-amz-trailer` header
-    #   sent. Otherwise, Amazon S3 fails the request with the HTTP status code
-    #   `400 Bad Request`. For more information, see [Checking object
-    #   integrity][1] in the *Amazon S3 User Guide*.
+    #   when you use the SDK. This header will not provide any additional
+    #   functionality if you don't use the SDK. When you send this header,
+    #   there must be a corresponding `x-amz-checksum` or `x-amz-trailer`
+    #   header sent. Otherwise, Amazon S3 fails the request with the HTTP
+    #   status code `400 Bad Request`. For more information, see [Checking
+    #   object integrity][1] in the *Amazon S3 User Guide*.
     #
     #   If you provide an individual checksum, Amazon S3 ignores any provided
     #   `ChecksumAlgorithm` parameter.
@@ -230,13 +241,15 @@ module Aws::S3
     #
     #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
     # @option options [String] :expected_bucket_owner
-    #   The account ID of the expected bucket owner. If the bucket is owned by
-    #   a different account, the request fails with the HTTP status code `403
-    #   Forbidden` (access denied).
+    #   The account ID of the expected bucket owner. If the account ID that
+    #   you provide does not match the actual owner of the bucket, the request
+    #   fails with the HTTP status code `403 Forbidden` (access denied).
     # @return [EmptyStructure]
     def put(options = {})
       options = options.merge(bucket: @bucket_name)
-      resp = @client.put_bucket_logging(options)
+      resp = Aws::Plugins::UserAgent.feature('resource') do
+        @client.put_bucket_logging(options)
+      end
       resp.data
     end
 
